/*!
 * Lazy Load - JavaScript plugin for lazy loading images
 *
 * Copyright (c) 2007-2019 Mika Tuupola
 *
 * Licensed under the MIT license:
 *   http://www.opensource.org/licenses/mit-license.php
 *
 * Project home:
 *   https://appelsiini.net/projects/lazyload
 *
 * Version: 2.0.0-rc.2
 *
 */

(function (root, factory) {
    if (typeof exports === "object") {
        module.exports = factory(root);
    } else if (typeof define === "function" && define.amd) {
        define([], factory);
    } else {
        root.LazyLoad = factory(root);
    }
}) (typeof global !== "undefined" ? global : this.window || this.global, function (root) {

    "use strict";

    if (typeof define === "function" && define.amd){
        root = window;
    }

    const defaults = {
        src: "data-src",
        srcset: "data-srcset",
        selector: ".lazyload",
        root: null,
        rootMargin: "0px",
        threshold: 0
    };

    /**
    * Merge two or more objects. Returns a new object.
    * @private
    * @param {Boolean}  deep     If true, do a deep (or recursive) merge [optional]
    * @param {Object}   objects  The objects to merge together
    * @returns {Object}          Merged values of defaults and options
    */
    const extend = function ()  {

        let extended = {};
        let deep = false;
        let i = 0;
        let length = arguments.length;

        /* Check if a deep merge */
        if (Object.prototype.toString.call(arguments[0]) === "[object Boolean]") {
            deep = arguments[0];
            i++;
        }

        /* Merge the object into the extended object */
        let merge = function (obj) {
            for (let prop in obj) {
                if (Object.prototype.hasOwnProperty.call(obj, prop)) {
                    /* If deep merge and property is an object, merge properties */
                    if (deep && Object.prototype.toString.call(obj[prop]) === "[object Object]") {
                        extended[prop] = extend(true, extended[prop], obj[prop]);
                    } else {
                        extended[prop] = obj[prop];
                    }
                }
            }
        };

        /* Loop through each object and conduct a merge */
        for (; i < length; i++) {
            let obj = arguments[i];
            merge(obj);
        }

        return extended;
    };

    function LazyLoad(images, options) {
        this.settings = extend(defaults, options || {});
        this.images = images || document.querySelectorAll(this.settings.selector);
        this.observer = null;
        this.init();
    }

    LazyLoad.prototype = {
        init: function() {

            /* Without observers load everything and bail out early. */
            if (!root.IntersectionObserver) {
                this.loadImages();
                return;
            }

            let self = this;
            let observerConfig = {
                root: this.settings.root,
                rootMargin: this.settings.rootMargin,
                threshold: [this.settings.threshold]
            };

            this.observer = new IntersectionObserver(function(entries) {
                Array.prototype.forEach.call(entries, function (entry) {
                    if (entry.isIntersecting) {
                        self.observer.unobserve(entry.target);
                        let src = entry.target.getAttribute(self.settings.src);
                        let srcset = entry.target.getAttribute(self.settings.srcset);
                        if ("img" === entry.target.tagName.toLowerCase()) {
                            if (src) {
                                entry.target.src = src;
                            }
                            if (srcset) {
                                entry.target.srcset = srcset;
                            }
                        }
						else if( "iframe" === entry.target.tagName.toLowerCase() ){
	                            if (src) {
                                entry.target.src = src;
                            }						
						}
						else {
                            entry.target.style.backgroundImage = "url(" + src + ")";
                        }
						entry.target.classList.add("visible");
                    }
                });
            }, observerConfig);

            Array.prototype.forEach.call(this.images, function (image) {
                self.observer.observe(image);
            });
        },

        loadAndDestroy: function () {
            if (!this.settings) { return; }
            this.loadImages();
            this.destroy();
        },

        loadImages: function () {
            if (!this.settings) { return; }

            let self = this;
            Array.prototype.forEach.call(this.images, function (image) {
                let src = image.getAttribute(self.settings.src);
                let srcset = image.getAttribute(self.settings.srcset);
                if ("img" === image.tagName.toLowerCase()) {
                    if (src) {
                        image.src = src;
                    }
                    if (srcset) {
                        image.srcset = srcset;
                    }
                } else {
                    image.style.backgroundImage = "url('" + src + "')";
                }
				image.classList.add("visible");
            });
			
        },

        destroy: function () {
            if (!this.settings) { return; }
            this.observer.disconnect();
            this.settings = null;
        }
    };

    root.lazyload = function(images, options) {
        return new LazyLoad(images, options);
    };

    if (root.jQuery) {
        const $ = root.jQuery;
        $.fn.lazyload = function (options) {
            options = options || {};
            options.attribute = options.attribute || "data-src";
            new LazyLoad($.makeArray(this), options);
            return this;
        };
    }

    return LazyLoad;
});


/*
	A JavaScript plugin for lazy-loading responsive Google Adsense ads.
	-
	By Osvaldas Valutis, www.osvaldas.info
	Available for use under the MIT License
*/

;( function( $, window, document, undefined )
{
	'use strict';

	var $win			= $( window ),
		throttle		= function(a,b){var c,d;return function(){var e=this,f=arguments,g=+new Date;c&&g<c+a?(clearTimeout(d),d=setTimeout(function(){c=g,b.apply(e,f)},a)):(c=g,b.apply(e,f))}},

		scriptUrl		= '//pagead2.googlesyndication.com/pagead/js/adsbygoogle.js',
		scriptLoaded	= false,
		throttleTO		= 250,

		$adsLoaded		= $([]),
		$adsToLoad		= $([]),
		$adsPending		= $([]),

		loadAd			= function( $ad )
		{
			( adsbygoogle = window.adsbygoogle || []).push({});

			var onLoadFn = $ad.data( 'alOptions' ).onLoad;
			if( typeof onLoadFn === 'function' )
			{
				$ad.find( 'iframe' ).one( 'load', function()
				{
					onLoadFn( $ad );
				});
			}
		},
		getAdWidth = function( ad )
		{
			return parseInt( window.getComputedStyle( ad, ':before' ).getPropertyValue( 'content' ).slice( 1, -1 ) || 9999 );
		},
		initAds = function()
		{
			if( !$adsToLoad.length ) return true;

			var winScroll = $win.scrollTop(),
				winHeight = $win.height();

			$adsToLoad.each( function()
			{
				var $this		= $( this ),
					thisOpts	= $this.data( 'alOptions' ),
					laziness	= thisOpts.laziness + 1,
					offset		= $this.offset().top;

				// if the element is too far below || too far above
				if( offset - winScroll > winHeight * laziness || winScroll - offset - $this.outerHeight() - ( winHeight * laziness ) > 0 )
					return true;

				$adsToLoad	= $adsToLoad.not( $this );
				$adsLoaded	= $adsLoaded.add( $this );

				$this
				.data( 'alOriginalHTML', $this.html())
				.data( 'alWidth', getAdWidth( this ))
				.children( ':first' )
				.addClass( 'adsbygoogle' );

				if( typeof adsbygoogle !== 'undefined' ) loadAd( $this );
				else $adsPending = $adsPending.add( $this );

				if( !scriptLoaded )
				{
					scriptLoaded = true;
					$.ajax(
					{
						url:		scriptUrl,
						async:		true,
						cache:		true,
						dataType:	'script',
						success:	function()
						{
							$adsPending.each( function()
							{
								loadAd( $( this ));
							});
							$adsPending = $([]);
						}
					});
				}
			});
		},
		resizeAds = function()
		{
			if( !$adsLoaded.length ) return true;

			var anyNew = false;
			$adsLoaded.each( function()
			{
				var $this = $( this );
				if( $this.data( 'alWidth' ) != getAdWidth( this ))
				{
					$adsLoaded = $adsLoaded.not( $this );
					$this.html(  $this.data( 'alOriginalHTML' ));
					$adsToLoad	= $adsToLoad.add( $this );
					anyNew		= true;
				}
			});
			if( anyNew ) initAds();
		};

	$win
	.on( 'scroll resize', throttle( throttleTO, initAds ))
	.on( 'resize', throttle( throttleTO, resizeAds ));

	$.fn.adsenseLoader = function( options )
	{
		if( typeof options !== 'string' )
		{
			options = $.extend({},
			{
				laziness:	1,
				onLoad:		false
			},
			options );
		}

		this.each( function()
		{
			var $this = $( this );

			if( options === 'destroy' )
			{
				$this.html( $this.data( 'alOriginalHTML' ));
				$adsToLoad	= $adsToLoad.not( $this );
				$adsLoaded	= $adsLoaded.not( $this );
				$adsPending	= $adsPending.not( $this );
			}
			else
			{
				$this.data( 'alOptions', options );
				$adsToLoad = $adsToLoad.add( $this );
			}
		});

		if( options !== 'destroy' )
			initAds();

		return this;
	};

	$.adsenseLoaderConfig = function( options )
	{
		if( typeof options.scriptUrl !== 'undefined' )
			scriptUrl = options.scriptUrl;

		if( typeof options.throttle !== 'undefined' )
			throttleTO = options.throttle;
	};

})( jQuery, window, document );



(function($){
	
	"use strict";
	
	/*
	var imgs = document.getElementsByTagName( 'img' );

	for( var i = 0; i < imgs.length; i++ ) {
		
		//get srcset 
		var currentSrc = imgs[i].getAttribute('srcset');
		
		//get image class
		var img_class = imgs[i].getAttribute('class');

		if ( currentSrc != null ){
		  imgs[i].setAttribute( 'src', object_name.url + '/images/placeholder-full-single.png' ); // remove src and add placeholder
		  imgs[i].setAttribute( 'class', img_class + ' cover-image lazyload' ); // add class lazy
		  imgs[i].removeAttribute( 'srcset','' ); // remove srcset
		  imgs[i].setAttribute( 'data-srcset', currentSrc ); //add new srcset with "data-srcset" 
		}		
	}
	*/
			
	$( ".post-content img, .page-content img, .author-box img, .gallery-item img, .entry-attachment img" ).each(function() {
		
		var src = $(this).attr('src');
		var srcset = $(this).attr('srcset');
		$(this).attr('src',object_name.url + '/images/placeholder-full-single.png');
		$(this).attr('data-src',src);
		$(this).attr('srcset','');
		$(this).addClass('lazyload');
		$(this).attr('data-srcset',srcset);
	});

	$(".lazyload").lazyload();
})(jQuery);




(function($){
    "use strict";
	$( '.adsense.ads-lazy' ).adsenseLoader();
})(jQuery);